@@ -317,7 +317,7 @@ def default_model():
     curr_dir = os.getcwd()
     if os.path.commonprefix([models_dir, curr_dir]) == models_dir and \
        curr_dir != models_dir:
-        latest_model = get_latest_model(curr_dir)
+        latest_model = get_latest_folder(curr_dir)
     else:
         latest_model = get_latest_folder(models_dir)
     return latest_model
